Keywords: Supreme Court of the United States, Supreme Court, Supreme Court of US, Supremecourt, United State Supreme Court, US Supreme Court, U.S. Supreme Court, Court, Opinions, Slip Opinions

Visiting the Court | Touring the Building | Exhibitions

Search: All Documents Docket Advanced Search
Enter Search Text: Search term too short Invalid text in search term. Try again

Home | Opinions | 2015 Term Opinions of the Court

### 2015 Term Opinions of the Court

Slip Opinions, Per Curiams (PC), and Original Case Decrees (D)

The "slip" opinion is the second version of an opinion. It is sent to the printer later in the day on which the "bench" opinion is released by the Court. Each slip opinion has the same elements as the bench opinion--majority or plurality opinion, concurrences or dissents, and a prefatory syllabus--but may contain corrections not appearing in the bench opinion. The slip opinions collected here are those issued during October Term 2015 (October 5, 2015, through October 2, 2016). These opinions are posted on the Website within minutes after the bench opinions are issued and will remain posted until the opinions for the entire Term are published in the bound volumes of the United States Reports. For further information, see Column Header Definitions and Information About Opinions.

Caution: These electronic opinions may contain computer-generated errors or other deviations from the official printed slip opinion pamphlets. Moreover, a slip opinion is replaced by a paginated version of the case in the preliminary print, and, subsequently, by the final version of the case in a U. S. Reports bound volume. In case of discrepancies between the print and electronic versions of a slip opinion, the print version controls. However, where the electronic version has been designated “revised,” the electronic version controls to the extent that it differs from the print version with regard to the noted revision. In case of discrepancies between the slip opinion and any later official version of the opinion—i.e., the preliminary print or bound volume version—the later version controls.

R- | Date | Docket | Name | Revised | J. | Pt.
--- | --- | --- | --- | --- | --- | ---
18 | 1/25/16 | 15-278 | Amgen Inc. v. Harris |  | PC | 577/2
17 | 1/25/16 | 15-493 | James v. Boise |  | PC | 577/2
16 | 1/25/16 | 14-840 | FERC v. Electric Power Supply Assn. | 1/28/16 | EK | 577/2
15 | 1/25/16 | 14-510 | Menominee Tribe of Wis. v. United States |  | A | 577/2
14 | 1/25/16 | 14-1095 | Musacchio v. United States |  | T | 577/2
13 | 1/25/16 | 14-280 | Montgomery v. Louisiana | 1/27/16 | K | 577/2
12 | 1/20/16 | 14-1516 | Duncan v. Owens |  | PC | 577/1
11 | 1/20/16 | 14-857 | Campbell-Ewald v. Gomez | 2/09/16 | G | 577/1
10 | 1/20/16 | 14-723 | Montanile v. Board of Trustees of Nat. Elevator Industry Health Benefit Plan |  | T | 577/1
9 | 1/20/16 | 14-449 | Kansas v. Carr |  | AS | 577/1
8 | 1/12/16 | 14-7505 | Hurst v. Florida |  | SS | 577/1
7 | 1/12/16 | 14-844 | Bruce v. Samuels |  | G | 577/1
6 | 12/14/15 | 14-1372 | White v. Wheeler |  | PC | 577/1
5 | 12/14/15 | 14-462 | DIRECTV, Inc. v. Imburgia |  | B | 577/1
4 | 12/08/15 | 14-990 | Shapiro v. McManus |  | AS | 577/1
3 | 12/01/15 | 13-1067 | OBB Personenverkehr AG v. Sachs |  | R | 577/1
2 | 11/09/15 | 14-1143 | Mullenix v. Luna |  | PC | 577/1
1 | 10/05/15 | 14-848 | Maryland v. Kulbicki |  | PC | 577/1

February 11, 2016 | Version 2014.1
Home | Help | Site Map | Contact Us | About Us | FAQ | Jobs | Links | Building Regulations
Website Policies and Notices | Privacy Policy | USA.GOV
Supreme Court of the United States